@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,7 +7,8 @@
 #define NOTEACTIONCONFIG_H
 #include "noteshared_export.h"
 #include <KCModule>
-namespace NoteShared {
+namespace NoteShared
+{
 class NOTESHARED_EXPORT NoteActionConfig : public KCModule
 {
     Q_OBJECT
