@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -8,15 +8,15 @@
 
 #include "notesharedglobalconfig.h"
 
-#include <QLineEdit>
 #include <KLocalizedString>
+#include <QLineEdit>
 #include <QSpinBox>
 
-#include <QLabel>
 #include <QCheckBox>
+#include <QGroupBox>
+#include <QLabel>
 #include <QVBoxLayout>
 #include <QWhatsThis>
-#include <QGroupBox>
 
 using namespace NoteShared;
 class NoteShared::NoteNetworkConfigWidgetPrivate
@@ -35,11 +35,11 @@ NoteNetworkConfigWidget::NoteNetworkConfigWidget(QWidget *parent)
     : QWidget(parent)
     , d(new NoteShared::NoteNetworkConfigWidgetPrivate)
 {
-    auto *layout = new QVBoxLayout(this);
+    auto layout = new QVBoxLayout(this);
     layout->setContentsMargins(0, 0, 0, 0);
 
     QGroupBox *incoming = new QGroupBox(i18n("Incoming Notes"));
-    auto *tmpLayout = new QHBoxLayout;
+    auto tmpLayout = new QHBoxLayout;
 
     d->mTmpChkB = new QCheckBox(i18n("Accept incoming notes"));
     d->mTmpChkB->setObjectName(QStringLiteral("kcfg_ReceiveNotes"));
@@ -99,9 +99,9 @@ void NoteNetworkConfigWidget::load()
 NoteNetworkConfig::NoteNetworkConfig(QWidget *parent)
     : KCModule(parent)
 {
-    auto *lay = new QVBoxLayout(this);
+    auto lay = new QVBoxLayout(this);
     lay->setContentsMargins(0, 0, 0, 0);
-    auto *noteNetworkConfigWidget = new NoteNetworkConfigWidget(this);
+    auto noteNetworkConfigWidget = new NoteNetworkConfigWidget(this);
     lay->addWidget(noteNetworkConfigWidget);
     addConfig(NoteShared::NoteSharedGlobalConfig::self(), noteNetworkConfigWidget);
     load();
