@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,17 +7,19 @@
 #define NOTENETWORKCONFIG_H
 #include "noteshared_export.h"
 #include <KCModule>
-namespace NoteShared {
+namespace NoteShared
+{
 class NoteNetworkConfigWidgetPrivate;
 class NOTESHARED_EXPORT NoteNetworkConfigWidget : public QWidget
 {
     Q_OBJECT
 public:
     explicit NoteNetworkConfigWidget(QWidget *parent = nullptr);
-    ~NoteNetworkConfigWidget();
+    ~NoteNetworkConfigWidget() override;
 
     void save();
     void load();
+
 private:
     NoteNetworkConfigWidgetPrivate *const d;
 };
