@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -13,7 +13,7 @@ class KNotesTray : public KStatusNotifierItem
     Q_OBJECT
 public:
     explicit KNotesTray(QWidget *parent = nullptr);
-    ~KNotesTray();
+    ~KNotesTray() override;
 
     void updateNumberOfNotes(int value);
 
