@@ -1,38 +1,38 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "knotecollectionconfigwidget.h"
 #include "attributes/showfoldernotesattribute.h"
-#include <Akonadi/Notes/NoteUtils>
 #include "notesharedglobalconfig.h"
+#include <Akonadi/Notes/NoteUtils>
 #include <AkonadiWidgets/ManageAccountWidget>
 
-#include <AkonadiCore/CollectionModifyJob>
 #include <AkonadiCore/CollectionFilterProxyModel>
-#include <QSortFilterProxyModel>
+#include <AkonadiCore/CollectionModifyJob>
 #include <QInputDialog>
+#include <QSortFilterProxyModel>
 
-#include <AkonadiWidgets/CollectionRequester>
 #include <AkonadiCore/ChangeRecorder>
-#include <AkonadiCore/EntityTreeModel>
-#include <AkonadiWidgets/EntityTreeView>
 #include <AkonadiCore/EntityDisplayAttribute>
+#include <AkonadiCore/EntityTreeModel>
+#include <AkonadiWidgets/CollectionRequester>
+#include <AkonadiWidgets/EntityTreeView>
 
 #include <KMime/Message>
 
 #include <KCheckableProxyModel>
 
-#include <KLocalizedString>
-#include <QPushButton>
-#include <QLineEdit>
 #include "knotes_kcm_debug.h"
+#include <KLocalizedString>
 #include <KMessageBox>
+#include <QLineEdit>
+#include <QPushButton>
 
-#include <QVBoxLayout>
 #include <QHBoxLayout>
 #include <QLabel>
+#include <QVBoxLayout>
 
 KNoteCollectionDisplayProxyModel::KNoteCollectionDisplayProxyModel(QObject *parent)
     : QIdentityProxyModel(parent)
@@ -43,8 +43,7 @@ QVariant KNoteCollectionDisplayProxyModel::data(const QModelIndex &index, int ro
 {
     if (role == Qt::CheckStateRole) {
         if (index.isValid()) {
-            const Akonadi::Collection collection
-                = data(index, Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
+            const Akonadi::Collection collection = data(index, Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
             if (mDisplayCollection.contains(collection)) {
                 return mDisplayCollection.value(collection) ? Qt::Checked : Qt::Unchecked;
             } else {
@@ -63,8 +62,7 @@ bool KNoteCollectionDisplayProxyModel::setData(const QModelIndex &index, const Q
 {
     if (role == Qt::CheckStateRole) {
         if (index.isValid()) {
-            const Akonadi::Collection collection
-                = data(index, Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
+            const Akonadi::Collection collection = data(index, Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
             mDisplayCollection[collection] = (value == Qt::Checked);
             Q_EMIT dataChanged(index, index);
             return true;
@@ -91,14 +89,14 @@ QHash<Akonadi::Collection, bool> KNoteCollectionDisplayProxyModel::displayCollec
 KNoteCollectionConfigWidget::KNoteCollectionConfigWidget(QWidget *parent)
     : QWidget(parent)
 {
-    auto *mainLayout = new QHBoxLayout(this);
+    auto mainLayout = new QHBoxLayout(this);
     mainLayout->setContentsMargins(0, 0, 0, 0);
 
-    auto *tabWidget = new QTabWidget;
+    auto tabWidget = new QTabWidget;
     mainLayout->addWidget(tabWidget);
 
     QWidget *collectionWidget = new QWidget;
-    auto *vbox = new QVBoxLayout;
+    auto vbox = new QVBoxLayout;
     collectionWidget->setLayout(vbox);
     tabWidget->addTab(collectionWidget, i18n("Folders"));
 
@@ -115,7 +113,7 @@ KNoteCollectionConfigWidget::KNoteCollectionConfigWidget(QWidget *parent)
     // Set the model to show only collections, not items.
     mModel->setItemPopulationStrategy(Akonadi::EntityTreeModel::NoItemPopulation);
 
-    auto *mimeTypeProxy = new Akonadi::CollectionFilterProxyModel(this);
+    auto mimeTypeProxy = new Akonadi::CollectionFilterProxyModel(this);
     mimeTypeProxy->setExcludeVirtualCollections(true);
     mimeTypeProxy->addMimeTypeFilters(QStringList() << Akonadi::NoteUtils::noteMimeType());
     mimeTypeProxy->setSourceModel(mModel);
@@ -132,7 +130,7 @@ KNoteCollectionConfigWidget::KNoteCollectionConfigWidget(QWidget *parent)
     mCollectionFilter->setDynamicSortFilter(true);
     mCollectionFilter->setFilterCaseSensitivity(Qt::CaseInsensitive);
 
-    auto *searchLine = new QLineEdit(this);
+    auto searchLine = new QLineEdit(this);
     searchLine->setPlaceholderText(i18n("Search..."));
     searchLine->setClearButtonEnabled(true);
     connect(searchLine, &QLineEdit::textChanged, this, &KNoteCollectionConfigWidget::slotSetCollectionFilter);
@@ -148,7 +146,7 @@ KNoteCollectionConfigWidget::KNoteCollectionConfigWidget(QWidget *parent)
     mFolderView->setModel(mCollectionFilter);
     connect(mFolderView->selectionModel(), &QItemSelectionModel::selectionChanged, this, &KNoteCollectionConfigWidget::slotUpdateButtons);
 
-    auto *hbox = new QHBoxLayout;
+    auto hbox = new QHBoxLayout;
     vbox->addLayout(hbox);
 
     QPushButton *button = new QPushButton(i18n("&Select All"), this);
@@ -167,8 +165,7 @@ KNoteCollectionConfigWidget::KNoteCollectionConfigWidget(QWidget *parent)
     vbox->addWidget(new QLabel(i18nc("@info", "Select the folder where the note will be saved:")));
     mDefaultSaveFolder = new Akonadi::CollectionRequester(Akonadi::Collection(NoteShared::NoteSharedGlobalConfig::self()->defaultFolder()));
     mDefaultSaveFolder->setMimeTypeFilter(QStringList() << Akonadi::NoteUtils::noteMimeType());
-    mDefaultSaveFolder->setContentMimeTypes(QStringList() << QStringLiteral("application/x-vnd.akonadi.note")
-                                                          << QStringLiteral("text/x-vnd.akonadi.note")
+    mDefaultSaveFolder->setContentMimeTypes(QStringList() << QStringLiteral("application/x-vnd.akonadi.note") << QStringLiteral("text/x-vnd.akonadi.note")
                                                           << QStringLiteral("inode/directory"));
     Akonadi::CollectionDialog::CollectionDialogOptions options;
     options |= Akonadi::CollectionDialog::AllowToCreateNewChildCollection;
@@ -179,15 +176,15 @@ KNoteCollectionConfigWidget::KNoteCollectionConfigWidget(QWidget *parent)
     vbox->addWidget(mDefaultSaveFolder);
 
     QWidget *accountWidget = new QWidget;
-    auto *vboxAccountWidget = new QVBoxLayout;
+    auto vboxAccountWidget = new QVBoxLayout;
     accountWidget->setLayout(vboxAccountWidget);
 
-    auto *manageAccountWidget = new Akonadi::ManageAccountWidget(this);
+    auto manageAccountWidget = new Akonadi::ManageAccountWidget(this);
     manageAccountWidget->setDescriptionLabelText(i18n("Notes accounts"));
     vboxAccountWidget->addWidget(manageAccountWidget);
 
     manageAccountWidget->setMimeTypeFilter(QStringList() << Akonadi::NoteUtils::noteMimeType());
-    manageAccountWidget->setCapabilityFilter(QStringList() << QStringLiteral("Resource"));  // show only resources, no agents
+    manageAccountWidget->setCapabilityFilter(QStringList() << QStringLiteral("Resource")); // show only resources, no agents
     tabWidget->addTab(accountWidget, i18n("Accounts"));
     slotUpdateButtons();
 }
@@ -220,18 +217,16 @@ void KNoteCollectionConfigWidget::slotRenameCollection()
     }
 
     bool ok;
-    const QString name = QInputDialog::getText(this, i18n("Rename Notes"),
-                                               i18n("Name:"), QLineEdit::Normal, title, &ok);
+    const QString name = QInputDialog::getText(this, i18n("Rename Notes"), i18n("Name:"), QLineEdit::Normal, title, &ok);
 
     if (ok) {
-        if (col.hasAttribute<Akonadi::EntityDisplayAttribute>()
-            && !col.attribute<Akonadi::EntityDisplayAttribute>()->displayName().isEmpty()) {
+        if (col.hasAttribute<Akonadi::EntityDisplayAttribute>() && !col.attribute<Akonadi::EntityDisplayAttribute>()->displayName().isEmpty()) {
             col.attribute<Akonadi::EntityDisplayAttribute>()->setDisplayName(name);
         } else if (!name.isEmpty()) {
             col.setName(name);
         }
 
-        auto *job = new Akonadi::CollectionModifyJob(col, this);
+        auto job = new Akonadi::CollectionModifyJob(col, this);
         connect(job, &Akonadi::CollectionModifyJob::result, this, &KNoteCollectionConfigWidget::slotCollectionModifyFinished);
         job->start();
     }
@@ -319,16 +314,14 @@ void KNoteCollectionConfigWidget::updateCollectionsRecursive()
 
 void KNoteCollectionConfigWidget::slotModifyJobDone(KJob *job)
 {
-    auto *modifyJob = qobject_cast<Akonadi::CollectionModifyJob *>(job);
+    auto modifyJob = qobject_cast<Akonadi::CollectionModifyJob *>(job);
     if (modifyJob && job->error()) {
         if (job->property("AttributeAdded").toBool()) {
-            qCWarning(KNOTES_MODULES_LOG) << "Failed to append ShowFolderNotesAttribute to collection"
-                                  << modifyJob->collection().id() << ":"
-                                  << job->errorString();
+            qCWarning(KNOTES_MODULES_LOG) << "Failed to append ShowFolderNotesAttribute to collection" << modifyJob->collection().id() << ":"
+                                          << job->errorString();
         } else {
-            qCWarning(KNOTES_MODULES_LOG) << "Failed to remove ShowFolderNotesAttribute from collection"
-                                  << modifyJob->collection().id() << ":"
-                                  << job->errorString();
+            qCWarning(KNOTES_MODULES_LOG) << "Failed to remove ShowFolderNotesAttribute from collection" << modifyJob->collection().id() << ":"
+                                          << job->errorString();
         }
     }
 }
