@@ -1,11 +1,11 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#include <config-knotes.h>
 #include "knotedisplayconfigwidget.h"
+#include <config-knotes.h>
 
 #include "attributes/notedisplayattribute.h"
 #include "attributes/notelockattribute.h"
@@ -21,7 +21,7 @@
 KNoteDisplayConfigWidget::KNoteDisplayConfigWidget(bool defaults, QWidget *parent)
     : QWidget(parent)
 {
-    auto *layout = new QGridLayout(this);
+    auto layout = new QGridLayout(this);
 
     QLabel *label_FgColor = new QLabel(i18n("&Text color:"), this);
     label_FgColor->setObjectName(QStringLiteral("label_FgColor"));
@@ -32,8 +32,7 @@ KNoteDisplayConfigWidget::KNoteDisplayConfigWidget(bool defaults, QWidget *paren
     label_FgColor->setBuddy(kcfg_FgColor);
     layout->addWidget(kcfg_FgColor, 0, 1);
 
-    QLabel *label_BgColor = new QLabel(i18n("&Background color:"),
-                                       this);
+    QLabel *label_BgColor = new QLabel(i18n("&Background color:"), this);
     label_BgColor->setObjectName(QStringLiteral("label_BgColor"));
     layout->addWidget(label_BgColor, 1, 0);
 
@@ -42,12 +41,10 @@ KNoteDisplayConfigWidget::KNoteDisplayConfigWidget(bool defaults, QWidget *paren
     label_BgColor->setBuddy(kcfg_BgColor);
     layout->addWidget(kcfg_BgColor, 1, 1);
 
-    kcfg_ShowInTaskbar
-        = new QCheckBox(i18n("&Show note in taskbar"), this);
-    kcfg_ShowInTaskbar->setObjectName(QStringLiteral("kcfg_ShowInTaskbar"));
 #if KDEPIM_HAVE_X11
-    kcfg_RememberDesktop
-        = new QCheckBox(i18n("&Remember desktop"), this);
+    kcfg_ShowInTaskbar = new QCheckBox(i18n("&Show note in taskbar"), this);
+    kcfg_ShowInTaskbar->setObjectName(QStringLiteral("kcfg_ShowInTaskbar"));
+    kcfg_RememberDesktop = new QCheckBox(i18n("&Remember desktop"), this);
     kcfg_RememberDesktop->setObjectName(QStringLiteral("kcfg_RememberDesktop"));
 #endif
     if (defaults) {
@@ -62,8 +59,7 @@ KNoteDisplayConfigWidget::KNoteDisplayConfigWidget(bool defaults, QWidget *paren
         kcfg_Width->setSingleStep(10);
         layout->addWidget(kcfg_Width, 2, 1);
 
-        QLabel *label_Height = new QLabel(i18n("Default &height:"),
-                                          this);
+        QLabel *label_Height = new QLabel(i18n("Default &height:"), this);
         layout->addWidget(label_Height, 3, 0);
 
         kcfg_Height = new QSpinBox(this);
@@ -73,13 +69,13 @@ KNoteDisplayConfigWidget::KNoteDisplayConfigWidget(bool defaults, QWidget *paren
         label_Height->setBuddy(kcfg_Height);
         layout->addWidget(kcfg_Height, 3, 1);
 
-        layout->addWidget(kcfg_ShowInTaskbar, 4, 0);
 #if KDEPIM_HAVE_X11
+        layout->addWidget(kcfg_ShowInTaskbar, 4, 0);
         layout->addWidget(kcfg_RememberDesktop, 5, 0);
 #endif
     } else {
-        layout->addWidget(kcfg_ShowInTaskbar, 2, 0);
 #if KDEPIM_HAVE_X11
+        layout->addWidget(kcfg_ShowInTaskbar, 2, 0);
         layout->addWidget(kcfg_RememberDesktop, 3, 0);
 #endif
     }
@@ -95,10 +91,10 @@ void KNoteDisplayConfigWidget::load(NoteShared::NoteDisplayAttribute *attr)
     if (attr) {
         kcfg_FgColor->setColor(attr->foregroundColor());
         kcfg_BgColor->setColor(attr->backgroundColor());
+#if KDEPIM_HAVE_X11
         kcfg_ShowInTaskbar->setChecked(attr->showInTaskbar());
-        if (kcfg_RememberDesktop) {
-            kcfg_RememberDesktop->setChecked(attr->rememberDesktop());
-        }
+        kcfg_RememberDesktop->setChecked(attr->rememberDesktop());
+#endif
         if (kcfg_Height) {
             kcfg_Height->setValue(attr->size().height());
         }
@@ -113,10 +109,10 @@ void KNoteDisplayConfigWidget::save(NoteShared::NoteDisplayAttribute *attr)
     if (attr) {
         attr->setForegroundColor(kcfg_FgColor->color());
         attr->setBackgroundColor(kcfg_BgColor->color());
+#if KDEPIM_HAVE_X11
         attr->setShowInTaskbar(kcfg_ShowInTaskbar->isChecked());
-        if (kcfg_RememberDesktop) {
-            attr->setRememberDesktop(kcfg_RememberDesktop->isChecked());
-        }
+        attr->setRememberDesktop(kcfg_RememberDesktop->isChecked());
+#endif
         if (kcfg_Height && kcfg_Width) {
             attr->setSize(QSize(kcfg_Width->value(), kcfg_Height->value()));
         }
