@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -10,23 +10,23 @@
 #include <AkonadiSearch/PIM/resultiterator.h>
 
 #include <KLocalizedString>
+#include <QIcon>
 #include <QLineEdit>
 #include <QPushButton>
-#include <QIcon>
 
-#include <QVBoxLayout>
-#include <QLabel>
-#include <QListWidget>
+#include <KConfigGroup>
 #include <KSharedConfig>
 #include <QDialogButtonBox>
-#include <KConfigGroup>
+#include <QLabel>
+#include <QListWidget>
 #include <QMenu>
+#include <QVBoxLayout>
 
 KNoteFindDialog::KNoteFindDialog(QWidget *parent)
     : QDialog(parent)
 {
     setWindowTitle(i18nc("@title:window", "Search Notes"));
-    auto *mainLayout = new QVBoxLayout(this);
+    auto mainLayout = new QVBoxLayout(this);
     QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Close, this);
     connect(buttonBox, &QDialogButtonBox::rejected, this, &KNoteFindDialog::reject);
     setAttribute(Qt::WA_DeleteOnClose);
@@ -66,9 +66,9 @@ void KNoteFindDialog::readConfig()
 KNoteFindWidget::KNoteFindWidget(QWidget *parent)
     : QWidget(parent)
 {
-    auto *vbox = new QVBoxLayout(this);
+    auto vbox = new QVBoxLayout(this);
     vbox->setContentsMargins(0, 0, 0, 0);
-    auto *hbox = new QHBoxLayout;
+    auto hbox = new QHBoxLayout;
     vbox->addLayout(hbox);
     QLabel *lab = new QLabel(i18nc("@label:textbox", "Search notes:"), this);
     hbox->addWidget(lab);
@@ -78,19 +78,16 @@ KNoteFindWidget::KNoteFindWidget(QWidget *parent)
     connect(mSearchLineEdit, &QLineEdit::textChanged, this, &KNoteFindWidget::slotTextChanged);
     hbox->addWidget(mSearchLineEdit);
 
-    mSearchButton = new QPushButton(QIcon::fromTheme(QStringLiteral("edit-find")),
-                                    i18nc("@action:button Search notes", "Search..."),
-                                    this);
+    mSearchButton = new QPushButton(QIcon::fromTheme(QStringLiteral("edit-find")), i18nc("@action:button Search notes", "Search..."), this);
     connect(mSearchButton, &QPushButton::clicked, this, &KNoteFindWidget::slotSearchNote);
     hbox->addWidget(mSearchButton);
     mSearchButton->setEnabled(false);
 
-    //Result
+    // Result
     mNoteList = new NoteShared::NoteListWidget(this);
     mNoteList->setContextMenuPolicy(Qt::CustomContextMenu);
     mNoteList->setSelectionMode(QAbstractItemView::SingleSelection);
-    connect(mNoteList, &NoteShared::NoteListWidget::itemDoubleClicked,
-            this, &KNoteFindWidget::slotItemDoubleClicked);
+    connect(mNoteList, &NoteShared::NoteListWidget::itemDoubleClicked, this, &KNoteFindWidget::slotItemDoubleClicked);
     connect(mNoteList, &NoteShared::NoteListWidget::customContextMenuRequested, this, &KNoteFindWidget::customContextMenuRequested);
     vbox->addWidget(mNoteList);
 
