@@ -1,20 +1,21 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 #ifndef KNOTEFINDDIALOG_H
 #define KNOTEFINDDIALOG_H
 
-#include <QDialog>
-#include <AkonadiCore/Item>
 #include "knotes_export.h"
+#include <AkonadiCore/Item>
+#include <QDialog>
 class QPushButton;
 class QLineEdit;
 class QListWidgetItem;
 class QListWidget;
 class QLabel;
-namespace NoteShared {
+namespace NoteShared
+{
 class NoteListWidget;
 }
 class KNoteFindWidget : public QWidget
@@ -22,7 +23,7 @@ class KNoteFindWidget : public QWidget
     Q_OBJECT
 public:
     explicit KNoteFindWidget(QWidget *parent = nullptr);
-    ~KNoteFindWidget();
+    ~KNoteFindWidget() override;
 
     void setExistingNotes(const QHash<Akonadi::Item::Id, Akonadi::Item> &notes);
 
