@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,22 +7,22 @@
 #include "knoteedit.h"
 
 #include <KActionCollection>
+#include <KLineEdit>
 #include <KLocalizedString>
 #include <KToolBar>
-#include <KLineEdit>
 
 #include <KXMLGUIBuilder>
 #include <KXMLGUIFactory>
 
+#include "knotes_kontact_plugin_debug.h"
+#include <KConfigGroup>
+#include <KSharedConfig>
 #include <QAction>
+#include <QDialogButtonBox>
 #include <QHBoxLayout>
 #include <QLabel>
-#include <QVBoxLayout>
-#include "knotes_kontact_plugin_debug.h"
-#include <KSharedConfig>
-#include <KConfigGroup>
-#include <QDialogButtonBox>
 #include <QPushButton>
+#include <QVBoxLayout>
 
 KNoteEditDialog::KNoteEditDialog(bool readOnly, QWidget *parent)
     : QDialog(parent)
@@ -34,7 +34,7 @@ KNoteEditDialog::KNoteEditDialog(bool readOnly, QWidget *parent)
 void KNoteEditDialog::init(bool readOnly)
 {
     setWindowTitle(readOnly ? i18nc("@title:window", "Show Popup Note") : i18nc("@title:window", "Edit Popup Note"));
-    auto *mainLayout = new QVBoxLayout(this);
+    auto mainLayout = new QVBoxLayout(this);
     QDialogButtonBox *buttonBox = new QDialogButtonBox(readOnly ? QDialogButtonBox::Close : QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     connect(buttonBox, &QDialogButtonBox::accepted, this, &KNoteEditDialog::accept);
     connect(buttonBox, &QDialogButtonBox::rejected, this, &KNoteEditDialog::reject);
@@ -57,10 +57,10 @@ void KNoteEditDialog::init(bool readOnly)
     mainLayout->addWidget(page);
     mainLayout->addWidget(buttonBox);
 
-    auto *layout = new QVBoxLayout(page);
+    auto layout = new QVBoxLayout(page);
     layout->setContentsMargins(0, 0, 0, 0);
 
-    auto *hbl = new QHBoxLayout();
+    auto hbl = new QHBoxLayout();
     layout->addLayout(hbl);
     QLabel *label = new QLabel(page);
     label->setText(i18nc("@label popup note name", "Name:"));
@@ -73,7 +73,7 @@ void KNoteEditDialog::init(bool readOnly)
     }
     hbl->addWidget(mTitleEdit, 1, Qt::AlignVCenter);
 
-    //TODO customize it
+    // TODO customize it
     mNoteEdit = new KNoteEdit(actionCollection(), page);
     mNoteEdit->setFocus();
 
