@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,15 +7,15 @@
 #ifndef KNOTEPRINTSELECTTHEMECOMBOBOX_H
 #define KNOTEPRINTSELECTTHEMECOMBOBOX_H
 
-#include <QComboBox>
 #include "knotes_export.h"
+#include <QComboBox>
 
 class KNOTES_EXPORT KNotePrintSelectThemeComboBox : public QComboBox
 {
     Q_OBJECT
 public:
     explicit KNotePrintSelectThemeComboBox(QWidget *parent = nullptr);
-    ~KNotePrintSelectThemeComboBox();
+    ~KNotePrintSelectThemeComboBox() override;
 
     Q_REQUIRED_RESULT QString selectedTheme() const;
 
